@@ -3,8 +3,7 @@
 
 utils::globalVariables(c(
   "year", "country_iso",
-  "country_name_english", "country_fullname_english",
-  "commodity_fullname_english", "section_fullname_english", "commodity_code", 
+  "country_name", "commodity_name", "section_name", "commodity_code", 
   "group_code", "trade_value_usd_exp", "trade_value_usd_imp",
   "trade_value_usd_top_exp", "trade_value_usd_top_imp",
   "gdp_deflator", "conversion_factor", "conversion_year", "year_from",
@@ -62,28 +61,11 @@ NULL
 #' @source Open Trade Statistics
 #' @format A data frame with 275 observations on the following 5 variables
 #' \describe{
-#'   \item{\code{country_iso}}{ISO-3 code of the country (e.g. "deu" means Germany)}
-#'   \item{\code{country_name_english}}{Country name (e.g. Germany)}
-#'   \item{\code{country_fullname_english}}{Country name with indications (e.g. Germany as "Germany (former Federal Republic of Germany until 1990)")}
-#'   \item{\code{continent_name_english}}{Continent where the country belongs to (e.g., Europe)}
-#'   \item{\code{continent_id}}{Numeric id of the continent where the country belongs to (e.g., 5)}
-#' }
-NULL
-
-#' OTS Countries Colors
-#'
-#' Unofficial colors to ease visualization for countries.
-#'
-#' @docType data
-#' @keywords datasets
-#' @name ots_countries_colors
-#' @usage ots_countries_colors
-#' @source Open Trade Statistics
-#' @format A data frame with 275 rows and 3 variables
-#' \describe{
-#'   \item{\code{country_iso}}{ISO code of the country (e.g. "chl" means Chile)}
-#'   \item{\code{continent_id}}{Numeric id of the continent}
-#'   \item{\code{country_color}}{Country hex color (e.g. '#D05555')}
+#'   \item{\code{country_iso}}{ISO-3 code of the country (e.g. "GBR")}
+#'   \item{\code{country_name}}{Country name (e.g. United Kingdom)}
+#'   \item{\code{continent_id}}{Numeric id of the continent where the country belongs to (e.g., 4)}
+#'   \item{\code{continent_name}}{Continent where the country belongs to (e.g., Europe)}
+#'   \item{\code{continent_color}}{Color assigned to each continent for visualization purposes (e.g., '#8abdb6')}
 #' }
 NULL
 
@@ -101,8 +83,12 @@ NULL
 #' \describe{
 #'   \item{\code{commodity_code}}{HS six digits commodity code (e.g. 010110)}
 #'   \item{\code{commodity_code_short}}{HS four digits commodity code (e.g. 0101)}
-#'   \item{\code{commodity_fullname_english}}{HS six digits commodity name (e.g. 'Horses, asses, mules and hinnies; live, pure-bred breeding animals')}
-#'   \item{\code{section_code}}{HS section code (e.g. '01')}
+#'   \item{\code{commodity_name}}{HS six digits commodity name (e.g. 'Horses, asses, mules and hinnies; live, pure-bred breeding animals')}
+#'   \item{\code{chapter_code}}{HS chapter code (e.g. 01)}
+#'   \item{\code{chapter_name}}{HS chapter name (e.g. 'Animals; live')}
+#'   \item{\code{section_code}}{HS section code (e.g. 01)}
+#'   \item{\code{section_name}}{HS section name (e.g. 'Live animals; animal products')}
+#'   \item{\code{section_color}}{Color assigned to each HS section for visualization purposes (e.g. '#74c0e2')}
 #' }
 NULL
 
@@ -119,39 +105,6 @@ NULL
 #' @format A data frame with 1,225 observations on the following 2 variables
 #' \describe{
 #'   \item{\code{commodity_code}}{HS four digits commodity code (e.g. 0101)}
-#'   \item{\code{commodity_fullname_english}}{HS four digits commodity names (e.g. 'Horses, asses, mules and hinnies; live')}
-#' }
-NULL
-
-#' OTS Sections
-#'
-#' Official section names from the Harmonized System rev 2012 (HS12).
-#'
-#' @docType data
-#' @keywords datasets
-#' @name ots_sections
-#' @usage ots_sections
-#' @source Adapted from UN COMTRADE
-#' @format A data frame with 22 rows and 2 variables
-#' \describe{
-#'   \item{\code{section_code}}{HS section code (e.g. '01')}
-#'   \item{\code{section_fullname_english}}{HS section name (e.g. 'Live animals and animal products')}
-#' }
-NULL
-
-#' OTS Sections Colors
-#'
-#' Unofficial colors to ease visualization for the sections in
-#' the Harmonized System rev 2012 (HS12).
-#'
-#' @docType data
-#' @keywords datasets
-#' @name ots_sections_colors
-#' @usage ots_sections_colors
-#' @source Open Trade Statistics
-#' @format A data frame with 22 rows and 2 variables
-#' \describe{
-#'   \item{\code{section_code}}{HS section code (e.g. '01')}
-#'   \item{\code{section_color}}{HS section color (e.g. '#74c0e2')}
+#'   \item{\code{commodity_name}}{HS four digits commodity names (e.g. 'Horses, asses, mules and hinnies; live')}
 #' }
 NULL
